summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2bc1d72869b62af05ae4feafd878203b526da8c5 (patch)
tree2676903bb600bd9646644856e354940471ad84e2 /kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp
parent937b2991d8e78166eea904c80ad04d34607017a4 (diff)
downloadtdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.tar.gz
tdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp')
-rw-r--r--kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp b/kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp
index 7b425696..9d5ee471 100644
--- a/kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp
+++ b/kopete/protocols/jabber/libiris/iris/xmpp-im/client.cpp
@@ -34,7 +34,7 @@
//! Client, you will need to manually invoke Tasks. Fortunately, the
//! process is very simple.
//!
//! The entire Task system is heavily founded on TQt. All Tasks have a tqparent,
//! except for the root Task, and are considered TQObjects. By using TQt's RTTI
//! facilities (TQObject::sender(), TQObject::isA(), etc), you can use a
//! "fire and forget" approach with Tasks.
@@ -469,7 +469,7 @@ void Client::streamCloseFinished()
static TQDomElement oldStyleNS(const TQDomElement &e)
{
// find closest tqparent with a namespace
TQDomNode par = e.parentNode();
while(!par.isNull() && par.namespaceURI().isNull())
par = par.parentNode();
@@ -1155,22 +1155,22 @@ public:
bool done;
};
-Task::Task(Task *tqparent)
-:TQObject(tqparent)
+Task::Task(Task *parent)
+:TQObject(parent)
{
init();
- d->client = tqparent->client();
+ d->client = parent->client();
d->id = client()->genUniqueId();
connect(d->client, TQT_SIGNAL(disconnected()), TQT_SLOT(clientDisconnected()));
}
-Task::Task(Client *tqparent, bool)
+Task::Task(Client *parent, bool)
:TQObject(0)
{
init();
- d->client = tqparent;
+ d->client = parent;
connect(d->client, TQT_SIGNAL(disconnected()), TQT_SLOT(clientDisconnected()));
}
@@ -1189,9 +1189,9 @@ void Task::init()
d->done = false;
}
-Task *Task::tqparent() const
+Task *Task::parent() const
{
- return (Task *)TQObject::tqparent();
+ return (Task *)TQObject::parent();
}
Client *Task::client() const
@@ -34,7 +34,7 @@
//! process is very simple.
//!
-//! The entire Task system is heavily founded on TQt. All Tasks have a tqparent,
+//! The entire Task system is heavily founded on TQt. All Tasks have a parent,
//! except for the root Task, and are considered TQObjects. By using TQt's RTTI
//! facilities (TQObject::sender(), TQObject::isA(), etc), you can use a
@@ -469,7 +469,7 @@ void Client::streamCloseFinished()
static TQDomElement oldStyleNS(const TQDomElement &e)
{
- // find closest tqparent with a namespace
+ // find closest parent with a namespace
TQDomNode par = e.parentNode();
while(!par.isNull() && par.namespaceURI().isNull())